#!/bin/sh
# Upgrade system: check for upgrades
# Copyright (C) 2001 by Erik Cumps <software@mind.be>

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# $Id: check-upgrade.sh,v 1.1 2001/02/20 00:43:54 slay Exp $
#
# $Log: check-upgrade.sh,v $
# Revision 1.1  2001/02/20 00:43:54  slay
# New upgrade system
#

#
# Exit codes:
#          0   everything ok
# $EXITERROR   script error
#      other   command error

# === Configuration section ===

VERSION="1.0"
# Error exit code
EXITERROR=255
CHECKSTART="<checkupdate status=\"start\"/>"
CHECKDONE="<checkupdate status=\"done\"/>"
START="<update status=\"start\" pkgname=\""
STOP="<update status=\"stop\" pkgname=\""
ERRORCODE="\" error=\""
CLOSE="\"/>"
LOG_INFO="<update cat=\"log\" level=\"info\">"
LOG_ERROR="<update cat=\"log\" level=\"error\">"
END_LOG="</update>"

# === Code section ===
if [ "$1" = "-z" ]; then
  echo -n $VERSION
  exit 0
fi

echo

echo $CHECKSTART

/home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(start)"
# check for arguments
PACKAGE=$1
if [ $PACKAGE ];then
  if [ -f $PACKAGE.tar.gz ]; then
    echo $START$PACKAGE".tar.gz"$CLOSE
    ./do-upgrade.sh $PACKAGE.tar.gz $PACKAGE
    ERROR=$?
    if [ $ERROR -eq 2 ]; then
      echo $LOG_ERROR "Failed to upgrade "$PACKAGE".tar.gz (ERROR:"$ERROR")"$END_LOG
      rm -f $PACKAGE.tar.gz
      echo $STOP$PACKAGE".tar.gz"$ERRORCODE$ERROR$CLOSE
      echo $CHECKDONE
      /home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(done)"
      exit $ERROR
    fi
    echo $STOP$PACKAGE".tar.gz"$ERRORCODE$ERROR$CLOSE
    echo $CHECKDONE
    /home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(done)"
    exit $ERROR
  fi
  echo $CHECKDONE
  /home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(done)"
  exit $EXITERROR
fi

# Check for upgrades

for pkg in *-*.tar.gz; do
  pkgbase=${pkg%.tar.gz}  
  pkgbase=$(echo $pkgbase | cut -b4-)
  echo
  echo $START$pkg$CLOSE
  ./do-upgrade.sh $pkg $pkgbase
  ERROR=$?
  if [ $ERROR -eq 2 ]; then
    # error!
    echo $LOG_ERROR "Failed to upgrade "$pkg" (ERROR:"$ERROR")"$END_LOG
    rm -f $pkg
    echo $STOP$pkg$ERRORCODE$ERROR$CLOSE
    echo $CHECKDONE
    /home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(done)"
    exit $ERROR
  fi
  echo $STOP$pkg$ERRORCODE$ERROR$CLOSE
done

echo
echo $CHECKDONE
# Done
/home/upgrade/tools/send_to_sock.elf /home/flm/local_socket "set_upgrade_status(done)"
exit 0
