#!/bin/sh

# Configuration Script: network activation
# Copyright (C) 2000 by Erik Cumps <software@mind.be>

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# $Id: config-ip.sh,v 1.10 2005/02/04 08:05:00 hr Exp $
#
# $Log: config-ip.sh,v $
# Revision 1.10  2005/02/04 08:05:00  hr
# Patch: remove dhcpcd pid file before starting
#
# Revision 1.9  2001/02/13 15:07:07  slay
# Patch: remove dhcpcd pid file before starting dhcpcd
#
# Revision 1.8  2000/11/30 15:41:26  slay
# Changed command output redirection
#
# Revision 1.7  2000/11/30 15:35:49  slay
# Updated script comments
#
# Revision 1.6  2000/11/30 15:30:44  slay
# Hide output from commands
#
# Revision 1.5  2000/11/30 14:58:34  slay
# Added route command again
# Added broadcast parameter
#
# Revision 1.4  2000/11/30 14:46:13  slay
# Updated paths of tools
# Removed route command
# Removed MAC handling
#
# Revision 1.3  2000/11/30 14:36:08  slay
# Fixed error handling code
#
# Revision 1.2  2000/11/30 14:35:01  slay
# Updated DHCP and static ip code
#
# Revision 1.1  2000/11/30 13:57:13  slay
# Network activation script
#

# Mode: static IP or DHCP, decided by stdin input:
#
# DHCP: line 0: DHCP\n
#       <EOF>
#
# stIP: line 0: iii.iii.iii.iii\n	# IP address
#       line 1: iii.iii.iii.iii\n	# netmask
#       line 2: iii.iii.iii.iii\n	# broadcast
#       line 3: iii.iii.iii.iii\n	# default gateway
#       <EOF>
#
# There's no parameter checking here!
#
# Exit codes:
#          0   everything ok
# $EXITERROR   script error
#      other   command errors

# === Configuration section ===

# Error exit code
EXITERROR=255

# === Code section ===

# Get and check first stdin line
read ip
if [ $? -ne 0 ]; then
  # input expected but none found!
  exit $EXITERROR
fi

# DHCP or static IP?
#kill -kill $(cat /etc/dhcpc/dhcpcd-eth0.pid)
kill `pidof dhcpcd`
rm -f /etc/dhcpc/dhcpcd-eth0.pid

if [ $ip = "DHCP" ]; then
  # DHCP!
  /sbin/route del default 1>/dev/NULL 2>/dev/NULL
  /sbin/dhcpcd -t 10 -R eth0 1>/dev/null 2>/dev/null
  exit $?
else
  # Static IP
  read nm
  if [ $? -ne 0 ]; then
    # input expected but none found!
    exit $EXITERROR
  fi
  read br
  if [ $? -ne 0 ]; then
    # input expected but none found!
    exit $EXITERROR
  fi
  read gw
  if [ $? -ne 0 ]; then
    # input expected but none found!
    exit $EXITERROR
  fi
  /sbin/ifconfig lo 127.0.0.1 netmask 255.0.0.0 up 1>/dev/null 2>/dev/null
  if [ $? -ne 0 ]; then
    # pass error on
    exit $?
  fi
  /sbin/ifconfig eth0 $ip netmask $nm broadcast $br up 1>/dev/null 2>/dev/null
  if [ $? -ne 0 ]; then
    # pass error on
    exit $?
  fi
  /sbin/route del default 1>/dev/null 2>/dev/null
  /sbin/route add default gw $gw 1>/dev/null 2>/dev/null
  if [ $? -ne 0 ]; then
    # pass error on
    exit $?
  fi
fi

# Done
exit 0

